@@ -15,7 +15,7 @@ import abstracts
 from aio.core.functional import async_property
 
 from envoy.base import utils
-from envoy.code.check import abstract, exceptions, typing
+from envoy.code.check import abstract, exceptions, interface, typing
 
 
 logger = logging.getLogger(__name__)
@@ -31,6 +31,7 @@ CONTRIB_METADATA_PATH = "contrib/extensions_metadata.yaml"
 EXTENSIONS_SCHEMA = "tools/extensions/extensions_schema.yaml"
 
 
+@abstracts.implementer(interface.IExtensionsCheck)
 class AExtensionsCheck(abstract.ACodeCheck, metaclass=abstracts.Abstraction):
     """Extensions check."""
 
@@ -74,12 +75,10 @@ class AExtensionsCheck(abstract.ACodeCheck, metaclass=abstracts.Abstraction):
     @property
     def extension_security_postures(
             self) -> typing.ExtensionsSchemaSecurityPosturesList:
-        return self.extensions_schema["security_postures"]
-
-    @property
-    def extension_status_values(
-            self) -> typing.ExtensionsSchemaStatusValuesList:
-        return self.extensions_schema["status_values"]
+        return [
+            posture["name"]
+            for posture
+            in self.extensions_schema["security_postures"]]
 
     @cached_property
     def extensions_schema(self) -> typing.ExtensionsSchemaDict:
@@ -95,6 +94,14 @@ class AExtensionsCheck(abstract.ACodeCheck, metaclass=abstracts.Abstraction):
     def extensions_schema_path(self) -> pathlib.Path:
         return self.directory.path.joinpath(EXTENSIONS_SCHEMA)
 
+    @property
+    def extension_status_values(
+            self) -> typing.ExtensionsSchemaStatusValuesList:
+        return [
+            posture["name"]
+            for posture
+            in self.extensions_schema["status_values"]]
+
     @property
     def fuzz_test_path(self) -> pathlib.Path:
         return self.directory.path.joinpath(FUZZ_TEST_PATH)
